# Adding an edit button

Furo will automatically add a small edit button to each document, when the documentation is generated on Read the Docs using a GitHub repository as the source.

At this time, the edit button can not be added outside of the Read the Docs + GitHub combination. Further, it can not be disabled either for such a combination.
